#!/usr/bin/env bash
#
# Copyright (c) 2012 Avira Operations GmbH & Co. KG
#
# Description: Restarts or reloads the Avira ICAP. Used by the AVupdater in the POST action
# VERSION=1.0.0.7

if [ ! -z "$1" -a -d "$1" ]
then
    INSTALL_DIR="$1"
else
    INSTALL_DIR="$(pwd)"
fi
INSTALL_DIR=$(readlink -e "${INSTALL_DIR}")

# Available script modes: "restart", "reload"
SCRIPT_MODE="$2"
if [ -z ${SCRIPT_MODE} ]
then
    SCRIPT_MODE="restart"
fi

# Default Avira ICAP binary directory. Can be changed from icap_post_utils.sh script
ICAPBIN_DIR="${INSTALL_DIR}"

. "${INSTALL_DIR}/icap_post_utils.sh"

# Compute the utils file name
ICAPBIN_POST_UTILS_FILE=${ICAPBIN_POST_UTILS_FILE}-${SCRIPT_MODE}

# The full path to the Avira ICAP binary file
ICAPBIN_PATH="${ICAPBIN_DIR}/${ICAPBIN_NAME}"

# This will hold all the Avira ICAP pids of the processes that are running from the updated install directory
ICAPBIN_PIDS=()

# Get the PIDs of the running Avira ICAP processes
if [ ! -f "${INSTALL_DIR}/${ICAPBIN_POST_UTILS_FILE}" ]
then
    echo "ERROR: Pre step failed. Cannot find file '${INSTALL_DIR}/${ICAPBIN_POST_UTILS_FILE}'"

    # Remove the pids file
    rm -f "${INSTALL_DIR}/${ICAPBIN_POST_UTILS_FILE}"

    exit 1
fi

ICAPBIN_PIDS=($(cat "${INSTALL_DIR}/${ICAPBIN_POST_UTILS_FILE}"))

# No PID was returned -> no Avira ICAP is running
if [ 0 -eq "${#ICAPBIN_PIDS[@]}" ]
then
    echo "INFO: Avira ICAP is not running from '${ICAPBIN_DIR}'. Nothing to be done."

    # Remove the pids file
    rm -f "${INSTALL_DIR}/${ICAPBIN_POST_UTILS_FILE}"

    exit 0
fi

# Update each Avira ICAP process
for ((k = 0; $k < ${#ICAPBIN_PIDS[@]}; k++))
do
    case "${SCRIPT_MODE}" in
        "restart")
            restart_process_by_pid ${ICAPBIN_PIDS[$k]} "${ICAPBIN_PATH}" ${SHUTDOWN_TIMEOUT_SEC}
            ;;
        "reload")
            reload_process_by_pid ${ICAPBIN_PIDS[$k]}
            ;;
    esac
done

# Remove the pids file
rm -f "${INSTALL_DIR}/${ICAPBIN_POST_UTILS_FILE}"

# Exit from the script
exit 0
