#!/bin/bash
export PATH="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/X11"

eval $(ucr shell)

IKUAVDIR="/usr/lib/iku-av"
BASEDIR="$IKUAVDIR/bin"
TEMPLATEDIR="$IKUAVDIR/templates"

cd "$BASEDIR"

COMMAND="$2"

ENCOUNTFILE=/var/tmp/savapi-engine-updater.idx
PRCOUNTFILE=/var/tmp/savapi-product-updater.idx
LOCKFILE=/var/lock/updatesavapicron.lock

if [ "$iku_av_l10n" = "de" ]; then
	MAILTEMPLATE="$TEMPLATEDIR/update_error_de.txt"
else
	MAILTEMPLATE="$TEMPLATEDIR/update_error_en.txt"
fi

case "$iku_av_proxy" in
	"use_ucs_proxy")
		PROXYSTRING="$proxy_http"
		;;
	http://*)
		PROXYSTRING="$iku_av_proxy"
		;;
esac

LOGFILE="$iku_av_logfile"
[ "$LOGFILE" ] || exit 1
AVUPDATERARGS="--log=$LOGFILE --log-append"

if [ "$PROXYSTRING" ]; then
	PROXYSTRING=$(echo "$PROXYSTRING" | sed 's/http:\/\///')
	USERSTRING=$(echo "$PROXYSTRING" | cut -f1 -d@)
	PROXYSTRING=$(echo "$PROXYSTRING" | cut -f2 -d@)
	PROXYHOST=$(echo "$PROXYSTRING" | cut -f1 -d:)
	PROXYPORT=$(echo "$PROXYSTRING" | cut -f2 -d:)
	if [ "$USERSTRING" = "$PROXYSTRING" ]; then
		AVUPDATERARGS="$AVUPDATERARGS --proxy-host=$PROXYHOST --proxy-port=$PROXYPORT"
	else
		PROXYUSER=$(echo "$USERSTRING" | cut -f1 -d:)
		PROXYPASS=$(echo "$USERSTRING" | cut -f2- -d:)
		AVUPDATERARGS="$AVUPDATERARGS --proxy-host=$PROXYHOST --proxy-port=$PROXYPORT --proxy-username=\"$PROXYUSER\" --proxy-password=\"$PROXYPASS\""
	fi
fi
ERRORMAIL="$iku_av_errormail"
if [ "$iku_av_maxupdateerror" ]; then
	MAXUPDATEERROR="$iku_av_maxupdateerror"
else
	MAXUPDATEERROR="1"
fi
SAVAPIDIR="/usr/lib/iku-av"
SAVAPIBINDIR="$SAVAPIDIR/bin"

UPDATEERRORFILE=/var/tmp/savapi-updateerror.txt
UPDATEERRORCOUNT=$(cat /var/tmp/savapi-updateerror.txt 2>/dev/null)
[ "$UPDATEERRORCOUNT" ] || UPDATEERRORCOUNT=0


do_update(){
	/usr/lib/iku-av/bin/license-tool
	FQDN="$(hostname).$(ucr get domainname)"
	if "$SAVAPIBINDIR/avupdate.bin" $AVUPDATERARGS \
		--config="$CONFFILE" \
		--check-if-update-available >/dev/null 2>&1; then
		if [ "$COMMAND" = "check" ]; then
			echo "Update available, NOT updating."
		else
			echo "Update available, updating."
			if "$SAVAPIBINDIR/avupdate.bin" $AVUPDATERARGS \
				--config="$CONFFILE"; then
				echo "Update OK."
				UPDATEERRORCOUNT=0
				echo "$UPDATEERRORCOUNT" > "$UPDATEERRORFILE"
			else
				let UPDATEERRORCOUNT++
				if [ "$UPDATEERRORCOUNT" -ge "$MAXUPDATEERROR" ] && [ "$ERRORMAIL" ]; then
					"$BASEDIR/sendupdatemail.py"
					UPDATEERRORCOUNT=0
				fi
				echo "$UPDATEERRORCOUNT" > "$UPDATEERRORFILE"
				echo "Error while update."
				exit 1
			fi
		fi
	else
		if "$SAVAPIBINDIR/avupdate.bin" $AVUPDATERARGS \
			--config="$CONFFILE" \
			--check-if-update-available | grep -q "Nothing to update"; then
				echo "No update available."
		else
			if [ "$COMMAND" = "check" ]; then
				echo "Error getting update information."
			else
				let UPDATEERRORCOUNT++
				if [ "$UPDATEERRORCOUNT" -ge "$MAXUPDATEERROR" ] && [ "$ERRORMAIL" ]; then
					"$BASEDIR/sendupdatemail.py"
					UPDATEERRORCOUNT=0
				fi
				echo "$UPDATEERRORCOUNT" > "$UPDATEERRORFILE"
				echo "Error checking for update."
				exit 1
			fi
		fi
	fi

}


update(){
	case "$1" in
		engine)
			if [ "$COMMAND" = "check" ]; then
				echo "Checking for SAVAPI engine updates."
			else
				echo "Updating SAVAPI engine."
			fi
			CONFFILE="$SAVAPIBINDIR/avupdate-savapi-engine.conf"
			do_update
			CONFFILE="$SAVAPIBINDIR/avupdate-icap-engine.conf"
			do_update
			;;
		product)
			if [ "$COMMAND" = "check" ]; then
				echo "Checking for SAVAPI engine and product updates."
			else
				echo "Updating SAVAPI engine and product."
			fi
			CONFFILE="$SAVAPIBINDIR/avupdate-savapi-product.conf"
			do_update
			CONFFILE="$SAVAPIBINDIR/avupdate-icap-product.conf"
			do_update
			;;
		cron)
			[ -e "$LOCKFILE" ] && exit 1
			if [ -e "$ENCOUNTFILE" ]; then
				ENCOUNT=$(cat "$ENCOUNTFILE")
				if [ "$ENCOUNT" -gt 0 ]; then
					let ENCOUNT--
					echo  "$ENCOUNT" > "$ENCOUNTFILE"
				else
					ENCOUNT=$iku_av_engineupdateinterval
					echo  "$ENCOUNT" > "$ENCOUNTFILE"
					update "engine"
				fi
			else
				ENCOUNT=$iku_av_engineupdateinterval
				echo  "$ENCOUNT" > "$ENCOUNTFILE"
				update "engine"
			fi
			if [ -e "$PRCOUNTFILE" ]; then
				PRCOUNT=$(cat "$PRCOUNTFILE")
				if [ "$PRCOUNT" -gt 0 ]; then
					let PRCOUNT--
					echo  "$PRCOUNT" > "$PRCOUNTFILE"
				else
					PRCOUNT=$iku_av_productupdateinterval
					echo  "$PRCOUNT" > "$PRCOUNTFILE"
					update "product"
				fi
			else
				PRCOUNT=$iku_av_productupdateinterval
				echo  "$PRCOUNT" > "$PRCOUNTFILE"
				update "product"
			fi
			exit 0
			;;
		*)
			echo "Usage: $0 <engine|product> [check]"
			;;
	esac
}

update "$@"

exit 0
